@@ -1,9 +1,9 @@
 package Test::Smoke;
 use strict;
 
-# $Id: Smoke.pm 428 2003-09-21 12:41:17Z abeltje $
+# $Id: Smoke.pm 467 2003-10-10 10:22:00Z abeltje $
 use vars qw( $VERSION $conf @EXPORT );
-$VERSION = '1.18.06';
+$VERSION = '1.18.09';
 
 use base 'Exporter';
 @EXPORT  = qw( $conf &read_config &run_smoke );
@@ -96,18 +96,28 @@ sub do_manifest_check {
     }
 }
 
-=item run_smoke( $continue, $patch )
+=item run_smoke( [$continue[, @df_buildopts]] )
 
 C<run_smoke()> sets up de build environment and gets the private Policy
 file and build configurations and then runs the smoke stuff for all 
 configurations.
 
+All arguments after the C<$continue> are taken as default buildoptions
+and passed to C<./Configure>.
+
 =cut
 
 sub run_smoke {
     my $continue = shift;
     defined $continue or $continue = $conf->{continue};
-    my $patch = shift || Test::Smoke::Util::get_patch( $conf->{ddir} );
+
+    my @df_buildopts = @_ ? grep /^-[DUA]/ => @_ : ();
+    # We *always* want -Dusedevel!
+    push @df_buildopts, '-Dusedevel' 
+        unless grep /^-Dusedevel$/ => @df_buildopts;
+    Test::Smoke::BuildCFG->config( dfopts => join " ", @df_buildopts );
+
+    my $patch = Test::Smoke::Util::get_patch( $conf->{ddir} );
 
     exists $Config{ldlibpthname} && $Config{ldlibpthname} and
         $ENV{ $Config{ldlibpthname} } ||= '',
@@ -166,7 +176,7 @@ sub run_smoke {
 
 =head1 REVISION
 
-$Id: Smoke.pm 428 2003-09-21 12:41:17Z abeltje $
+$Id: Smoke.pm 467 2003-10-10 10:22:00Z abeltje $
 
 =head1 COPYRIGHT
 
