@@ -2,9 +2,9 @@
 use strict;
 $| = 1;
 
-# $Id: patchtree.pl 280 2003-07-28 20:01:35Z abeltje $
+# $Id: patchtree.pl 306 2003-08-01 16:57:12Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.006';
+$VERSION = '0.007';
 
 use Cwd;
 use File::Spec;
@@ -13,7 +13,9 @@ use lib File::Spec->catdir( $FindBin::Bin, 'lib' );
 use lib $FindBin::Bin;
 use Test::Smoke;
 use Test::Smoke::Patcher;
+use Test::Smoke::Util qw( do_pod2usage );
 
+my $myusage = "Usage: $0 -f <patchesfile> -d <destdir> [options]";
 use Getopt::Long;
 my %opt = (
     type    => 'multi',
@@ -78,10 +80,10 @@ GetOptions( \%opt,
     'help|h', 'man',
 
     'config|c:s',
-) or do_pod2usage( verbose => 1 );
+) or do_pod2usage( verbose => 1, myusage => $myusage );
 
-$opt{man}  and do_pod2usage( verbose => 2, exitval => 0 );
-$opt{help} and do_pod2usage( verbose => 1, exitval => 0 );
+$opt{ man} and do_pod2usage( verbose => 2, exitval => 0, myusage => $myusage );
+$opt{help} and do_pod2usage( verbose => 1, exitval => 0, myusage => $myusage );
 
 if ( defined $opt{config} ) {
     $opt{config} eq "" and $opt{config} = 'smokecurrent_config';
@@ -121,23 +123,6 @@ if ( $^O eq 'MSWin32' ) {
 my $patcher = Test::Smoke::Patcher->new( $opt{type} => \%opt );
 eval{ $patcher->patch };
 
-sub do_pod2usage {
-    eval { require Pod::Usage };
-    if ( $@ ) {
-        print <<EO_MSG;
-Usage: $0 -t <type> -d <directory> [options]
-
-Use 'perldoc $0' for the documentation.
-Please install 'Pod::Usage' for easy access to the docs.
-
-EO_MSG
-        my %p2u_opt = @_;
-        exit( exists $p2u_opt{exitval} ? $p2u_opt{exitval} : 1 );
-    } else {
-        Pod::Usage::pod2usage( @_ );
-    }
-}
-
 =head1 SEE ALSO
 
 L<Test::Smoke::Patcher>
