@@ -2,9 +2,9 @@
 use strict;
 $| = 1;
 
-# $Id: runsmoke.pl 247 2003-07-20 12:39:59Z abeltje $
+# $Id: runsmoke.pl 433 2003-09-23 18:26:59Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.001';
+$VERSION = '0.002';
 
 use Cwd;
 use File::Spec;
@@ -12,8 +12,9 @@ use FindBin;
 use lib File::Spec->catdir( $FindBin::Bin, 'lib' );
 use lib $FindBin::Bin;
 use Config;
+use Test::Smoke::Smoker;
 use Test::Smoke;
-use Test::Smoke::Util qw( calc_timeout );
+use Test::Smoke::Util qw( calc_timeout do_pod2usage );
 
 use Getopt::Long;
 my %opt = (
@@ -33,6 +34,8 @@ my %opt = (
     v              => undef,
 );
 
+my $defaults = Test::Smoke::Smoker->config( 'all_defaults' );
+
 =head1 NAME
 
 runsmoke.pl - Configure, build and test bleading edge perl
@@ -97,7 +100,7 @@ depricated and will not be maintained).
 
 =cut
 
-
+my $myusage = "Usage: $0 [options] <buildcfg>";
 GetOptions( \%opt,
     'config|c:s', 'ddir|d=s',
     'cfg=s',
@@ -111,13 +114,14 @@ GetOptions( \%opt,
     'w32cc|win32-cctype=s',
 
     'dry_run|dry-run|n', 'run!',
+    'continue!',
     'v|verbose=i',
 
     'help|h', 'man',
-) or do_pod2usage( verbose => 1 );
+) or do_pod2usage( verbose => 1, myusage => $myusage );
 
-$opt{man}  and do_pod2usage( verbose => 2, exitval => 0 );
-$opt{help} and do_pod2usage( verbose => 1, exitval => 0 );
+$opt{ man} and do_pod2usage( verbose => 2, exitval => 0, myusage => $myusage );
+$opt{help} and do_pod2usage( verbose => 1, exitval => 0, myusage => $myusage );
 
 if ( defined $opt{config} ) {
     $opt{config} eq "" and $opt{config} = 'smokecurrent_config';
@@ -142,6 +146,12 @@ if ( defined $opt{config} ) {
 }
 
 $opt{cfg} = shift @ARGV if ! $opt{cfg} && @ARGV && -f $ARGV[0];
+$opt{run} = 0 if $opt{dry_run};
+foreach ( keys %$defaults ) {
+    next if defined $opt{ $_ };
+    $opt{ $_ } = exists $conf->{ $_ } ? $conf->{ $_ } : $defaults->{ $_ };
+}
+
 # transfer %opt to %$conf
 $conf->{ $_ } = $opt{ $_ } for keys %opt;
 @ARGV and push @{ $conf->{w32args} }, @ARGV;
@@ -162,24 +172,7 @@ $timeout and local $SIG{ALRM} = sub {
 };
 $Config{d_alarm} and alarm $timeout;
 
-run_smoke();
-
-sub do_pod2usage {
-    eval { require Pod::Usage };
-    if ( $@ ) {
-        print <<EO_MSG;
-Usage: $0 [options] <buildcfg>
-
-Use 'perldoc $0' for the documentation.
-Please install 'Pod::Usage' for easy access to the docs.
-
-EO_MSG
-        my %p2u_opt = @_;
-        exit( exists $p2u_opt{exitval} ? $p2u_opt{exitval} : 1 );
-    } else {
-        Pod::Usage::pod2usage( @_ );
-    }
-}
+run_smoke( $conf->{continue} );
 
 =head1 SEE ALSO
 
