@@ -1,16 +1,17 @@
 package TestLib;
 use strict;
 
-# $Id: TestLib.pm 253 2003-07-20 23:19:05Z abeltje $
+# $Id: TestLib.pm 468 2003-10-10 12:33:59Z abeltje $
 use vars qw( $VERSION @EXPORT );
 $VERSION = '0.02';
 
 use base 'Exporter';
 @EXPORT = qw( 
-    &whereis 
+    &whereis
+    &find_a_patch
     &find_unzip &do_unzip
     &find_untargz &do_untargz
-    &get_dir &get_file 
+    &get_dir &get_file &put_file
     &rmtree &mkpath
 );
 
@@ -72,7 +73,7 @@ sub get_dir($) {
     my @files;
     find sub {
         -f or return;
-        (my $name = $File::Find::name ) =~ s/^\Q$path\E//;
+        my $name = File::Spec->abs2rel( $File::Find::name, $path );
         push @files, $name;
     }, $path;
 
@@ -102,6 +103,33 @@ sub get_file {
     return wantarray ? @content : join "", @content;
 }
 
+=item put_file( $content, @path )
+
+The contents of C<@path> are passed to B<< File::Spec->catfile() >>
+
+Writes C<$content> to that file and returns the success/failure.
+
+=cut
+
+sub put_file {
+    my $contents = shift;
+    my $filename = File::Spec->catfile( @_ );
+
+    local *MYFILE;
+    if ( open MYFILE, "> $filename" ) {
+        print MYFILE $contents;
+        close MYFILE or do {
+            warn "Cannot close (@{[cwd]})$filename: $!";
+            return;
+        };
+    } else {
+        warn "Cannot create (@{[cwd]})$filename: $!";
+        return;
+    }
+
+    return 1;
+}
+
 =item rmtree( @_ )
 
 This is B<< File::Path::rmtree() >>.
@@ -118,6 +146,22 @@ This is B<< File::Path::mkpath() >>.
 
 sub mkpath { File::Path::mkpath( @_ ) }
 
+=item find_a_patch()
+
+Loop over some known names for gnu-patch and see if they know about --version.
+
+=cut
+
+sub find_a_patch {
+
+    my $patch_bin;
+    foreach my $patch (qw( gpatch npatch patch )) {
+        $patch_bin = whereis( $patch ) or next;
+        my $version = `$patch_bin --version`;
+        $? or return $patch_bin;
+    }
+}
+
 =item find_unzip()
 
 Check C<< wheris( 'gzip' ) >> or C<< eval{ require Compress::Zlib } >>.
